@@ -1,3 +1,5 @@
+library(testthat)
+library(data.table)
 test_that("resampling error if no group", {
   itask <- mlr3::TaskClassif$new("iris", iris, target="Species")
   same_other <- mlr3resampling::ResamplingSameOtherCV$new()
@@ -81,15 +83,52 @@ test_that("error for group named test", {
   }, "col with role group must not be named test; please fix by renaming test col")
 })
 
-test_that("error for 10 data", {
+test_that("errors and result for 10 train data in small stratum", {
   size_cv <- mlr3resampling::ResamplingVariableSizeTrainCV$new()
-  i10.dt <- data.table(iris)[1:10]
-  i10.task <- mlr3::TaskClassif$new("i10", i10.dt, target="Species")
+  size_cv$param_set$values$folds <- 2
+  i10.dt <- data.table(iris)[1:70]
+  i10.task <- mlr3::TaskClassif$new(
+    "i10", i10.dt, target="Species"
+  )$set_col_roles("Species",c("target","stratum"))
   expect_error({
     size_cv$instantiate(i10.task)
   },
-  "task$nrow=10 but should be larger than min_train_data=10",
+  "max_train_data=10 (in smallest stratum) but should be larger than min_train_data=10, please fix by decreasing min_train_data",
   fixed=TRUE)
+  size_cv$param_set$values$min_train_data <- 9
+  expect_error({
+    size_cv$instantiate(i10.task)
+  },
+  "train sizes not unique, please decrease train_sizes",
+  fixed=TRUE)
+  size_cv$param_set$values$train_sizes <- 2
+  size_cv$instantiate(i10.task)
+  size.tab <- table(size_cv$instance$iteration.dt[["small_stratum_size"]])
+  expect_identical(names(size.tab), c("9","10"))
+})
+
+test_that("strata respected in all sizes", {
+  size_cv <- mlr3resampling::ResamplingVariableSizeTrainCV$new()
+  size_cv$param_set$values$min_train_data <- 5
+  size_cv$param_set$values$folds <- 5
+  N <- 100
+  imbalance <- 4
+  strat.vec <- ifelse((1:imbalance)<imbalance, "A","B")
+  istrat.dt <- data.table(iris[1:N,], strat=factor(rep(strat.vec, l=N)))
+  smallest.size.tab <- table(
+    istrat.dt[["strat"]]
+  )/N*imbalance*size_cv$param_set$values$min_train_data
+  istrat.task <- mlr3::TaskClassif$new(
+    "istrat", istrat.dt, target="Species"
+  )$set_col_roles("strat", "stratum")
+  size_cv$instantiate(istrat.task)
+  min.dt <- size_cv$instance$iteration.dt[train_size==min(train_size)]
+  for(min.i in 1:nrow(min.dt)){
+    min.row <- min.dt[min.i]
+    train.i <- min.row$train[[1]]
+    strat.tab <- table(istrat.dt[train.i, strat])
+    expect_equal(strat.tab, smallest.size.tab)
+  }
 })
 
 test_that("train set max size 67 for 100 data", {
